@@ -2,7 +2,7 @@
 # Function: catvar.size
 # Programmer: Tom Kincaid
 # Date: September 27, 2002
-# Last Revised: August 18, 2010
+# Last Revised: March 27, 2020
 #
 #' Variance Estimates of the Estimated Size for Categorical Data
 #'
@@ -207,16 +207,6 @@ catvar.size <- function(z, wgt, x, y, size, stratum.ind, stratum.level,
          }
       }
 
-# Assign the mean variance to stage one sampling units with a single stage two
-# sampling unit
-      for(j in 1:m) {
-         ind <- var2est[,j] == 0
-         if(sum(ind) > 0) {
-            var.mean <- mean(var2est[!ind,j])
-            var2est[ind,j] <- var.mean
-         }
-      }
-
 # Adjust the variance estimator for small sample size
 
       if(vartype == "Local" && ncluster < 4) {
