@@ -2,7 +2,7 @@
 # Function: cdfvar.test
 # Programmer: Tom Kincaid
 # Date: November 2, 2000
-# Last Revised: June 17, 2011
+# Last Revised: March 27, 2020
 #
 #' Variance-Covariance Matrix Estimate for Estimated Population Proportions
 #'
@@ -253,16 +253,6 @@ cdfvar.test <- function(z, wgt, x, y, bounds, phat, stratum.ind, stratum.level,
          }
       }
 
-# Assign the mean variance to stage one sampling units with a single stage two
-# sampling unit
-      for(j in 1:m) {
-         ind <- var2est[,j] == 0
-         if(sum(ind) > 0) {
-            var.mean <- mean(var2est[!ind,j])
-            var2est[ind,j] <- var.mean
-         }
-      }
-
 # Adjust the variance estimator for small sample size
 
       if(vartype == "Local" && ncluster < 4) {
